@@ -1,19 +1,17 @@
 package Net::Riak::Bucket;
 BEGIN {
-  $Net::Riak::Bucket::VERSION = '0.14';
+  $Net::Riak::Bucket::VERSION = '0.15';
 }
-
-# ABSTRACT: Access and change information about a Riak bucket
-
-use JSON;
 use Moose;
-use Carp;
 use Net::Riak::Object;
-
+use Net::Riak::Types Client => {-as => 'Client_T'};
 with 'Net::Riak::Role::Replica' => {keys => [qw/r w dw/]};
-with 'Net::Riak::Role::Base' => {
-    classes => [{ name => 'client', required => 1, }]
-};
+
+has client => (
+    is       => 'rw',
+    isa      => Client_T,
+    required => 1,
+);
 
 has name => (
     is       => 'ro',
@@ -40,20 +38,17 @@ sub allow_multiples {
     my $self = shift;
 
     if (my $val = shift) {
-        my $bool = ($val == 1 ? JSON::true : JSON::false);
+        my $bool = ($val == 1 ? 1 : 0);
         $self->set_property('allow_mult', $bool);
     }
     else {
-        return $self->get_property('allow_mult');
+        return $self->get_property('allow_mult') ? 1 : 0;
     }
 }
 
 sub get_keys {
     my ($self, $params) = @_;
-    my $key_mode = delete($params->{stream}) ? 'stream' : 'true';
-    $params = { props => 'false', keys => $key_mode, %$params };
-    my $properties = $self->get_properties($params);
-    return $properties->{keys};
+    $self->client->get_keys($self->name, $params);
 }
 
 sub get {
@@ -69,12 +64,12 @@ sub get {
 }
 
 sub delete_object {
-    my ($self, $key) = @_;
+    my ($self, $key, $dw) = @_;
     Net::Riak::Object->new(
         client => $self->client,
         bucket => $self,
         key    => $key
-    )->delete;
+    )->delete($dw);
 }
 
 sub set_property {
@@ -90,59 +85,12 @@ sub get_property {
 
 sub get_properties {
     my ($self, $params) = @_;
-
-    # Callbacks require stream mode
-    $params->{keys}  = 'stream' if $params->{cb};
-
-    $params->{props} = 'true'  unless exists $params->{props};
-    $params->{keys}  = 'false' unless exists $params->{keys};
-
-    my $request = $self->client->new_request(
-        'GET', [$self->client->prefix, $self->name], $params
-    );
-
-    my $response = $self->client->send_request($request);
-
-    unless ($response->is_success) {
-        die "Error getting bucket properties: ".$response->status_line."\n";
-    }
-
-    if ($params->{keys} ne 'stream') {
-        return JSON::decode_json($response->content);
-    }
-
-    # In streaming mode, aggregate keys from the multiple returned chunk objects
-    else {
-        my $json = JSON->new;
-        my $props = $json->incr_parse($response->content);
-        if ($params->{cb}) {
-            while (defined(my $obj = $json->incr_parse)) {
-                $params->{cb}->($_) foreach @{$obj->{keys}};
-            }
-            return %$props ? { props => $props } : {};
-        }
-        else {
-            my @keys = map { $_->{keys} && ref $_->{keys} eq 'ARRAY' ? @{$_->{keys}} : () }
-                $json->incr_parse;
-            return { props => $props, keys => \@keys };
-        }
-    }
+    $self->client->get_properties($self->name, $params);
 }
 
 sub set_properties {
     my ($self, $props) = @_;
-
-    my $request = $self->client->new_request(
-        'PUT', [$self->client->prefix, $self->name]
-    );
-
-    $request->header('Content-Type' => $self->content_type);
-    $request->content(JSON::encode_json({props => $props}));
-
-    my $response = $self->client->send_request($request);
-    unless ($response->is_success) {
-        die "Error setting bucket properties: ".$response->status_line."\n";
-    }
+    $self->client->set_properties($self, $props);
 }
 
 sub new_object {
@@ -166,11 +114,11 @@ __END__
 
 =head1 NAME
 
-Net::Riak::Bucket - Access and change information about a Riak bucket
+Net::Riak::Bucket
 
 =head1 VERSION
 
-version 0.14
+version 0.15
 
 =head1 SYNOPSIS
 
@@ -184,7 +132,7 @@ version 0.14
     my $obj2 = $bucket->new_object('foo2', {...});
     $object->store;
 
-    $bucket->delete_object($key);
+    $bucket->delete_object($key, 3); # optional w val
 
 =head1 DESCRIPTION
 
@@ -317,7 +265,7 @@ A callback subroutine to be called for each key found (passed in as the only par
 
 =head1 AUTHOR
 
-franck cuny <franck@lumberjaph.net>
+franck cuny <franck@lumberjaph.net>, robin edwards <robin.ge@gmail.com>
 
 =head1 COPYRIGHT AND LICENSE
 
