@@ -1,14 +1,12 @@
 package Net::Riak::Client;
 BEGIN {
-  $Net::Riak::Client::VERSION = '0.14';
+  $Net::Riak::Client::VERSION = '0.15';
 }
 
 use Moose;
 use MIME::Base64;
-use Moose::Util::TypeConstraints;
 
-class_type 'HTTP::Request';
-class_type 'HTTP::Response';
+with 'MooseX::Traits';
 
 has prefix => (
     is      => 'rw',
@@ -30,41 +28,11 @@ has client_id => (
     isa        => 'Str',
     lazy_build => 1,
 );
-has http_request => (
-    is => 'rw',
-    isa => 'HTTP::Request',
-);
-
-has http_response => (
-    is => 'rw',
-    isa => 'HTTP::Response',
-    handles => ['is_success']
-);
-
-has ua_timeout => (
-    is  => 'rw',
-    isa => 'Int',
-    default => 3
-);
-
-with 'Net::Riak::Role::UserAgent';
-with qw/
-  Net::Riak::Role::REST
-  Net::Riak::Role::Hosts
-  /;
-
-
 
 sub _build_client_id {
     "perl_net_riak" . encode_base64(int(rand(10737411824)), '');
 }
 
-sub is_alive {
-    my $self     = shift;
-    my $request  = $self->new_request('GET', ['ping']);
-    my $response = $self->send_request($request);
-    $self->is_success ? return 1 : return 0;
-}
 
 1;
 
@@ -77,11 +45,11 @@ Net::Riak::Client
 
 =head1 VERSION
 
-version 0.14
+version 0.15
 
 =head1 AUTHOR
 
-franck cuny <franck@lumberjaph.net>
+franck cuny <franck@lumberjaph.net>, robin edwards <robin.ge@gmail.com>
 
 =head1 COPYRIGHT AND LICENSE
 
