@@ -1,32 +1,14 @@
 package Net::Riak::Role::Hosts;
 BEGIN {
-  $Net::Riak::Role::Hosts::VERSION = '0.14';
+  $Net::Riak::Role::Hosts::VERSION = '0.15';
 }
 
 use Moose::Role;
-use Moose::Util::TypeConstraints;
-
-subtype 'RiakHost' => as 'ArrayRef[HashRef]';
-
-coerce 'RiakHost' => from 'Str' => via {
-    [{node => $_, weight => 1}];
-};
-coerce 'RiakHost' => from 'ArrayRef' => via {
-    my $backends = $_;
-    my $weight   = 1 / @$backends;
-    [map { {node => $_, weight => $weight} } @$backends];
-};
-coerce 'RiakHost' => from 'HashRef' => via {
-    my $backends = $_;
-    my $total    = 0;
-    $total += $_ for values %$backends;
-    [map { {node => $_, weight => $backends->{$_} / $total} }
-          keys %$backends];
-};
+use Net::Riak::Types qw(RiakHost);
 
 has host => (
     is      => 'rw',
-    isa     => 'RiakHost',
+    isa     => RiakHost,
     coerce  => 1,
     default => 'http://127.0.0.1:8098',
 );
@@ -55,11 +37,11 @@ Net::Riak::Role::Hosts
 
 =head1 VERSION
 
-version 0.14
+version 0.15
 
 =head1 AUTHOR
 
-franck cuny <franck@lumberjaph.net>
+franck cuny <franck@lumberjaph.net>, robin edwards <robin.ge@gmail.com>
 
 =head1 COPYRIGHT AND LICENSE
 
